--- title: Changelog menu: docs.changelog layout: docs --- {% for version in site.data.changelog reversed %}
{{ version.version }} – {{ version.date | date: '%B %d, %Y' }}
{% if version.description %}

{{ version.description }}

{% endif %} {% if version.changes %}

{% for change in version.changes %}
- {{ change | markdownify | replace_regex: '\s+$', '' | replace_regex: '^

  ', '' | replace_regex: '#([0-9]+)', '#\1' }}

{% endfor %}

{% endif %}
{% endfor %}